#---
# Excerpted from "Rails Test Prescriptions",
# published by The Pragmatic Bookshelf.
# Copyrights apply to this code. It may not be used to create training material, 
# courses, books, articles, and the like. Contact us if you are in doubt.
# We make no guarantees that this code is fit for any purpose. 
# Visit http://www.pragmaticprogrammer.com/titles/nrtest for more book information.
#---
require 'test_helper'

class ProjectTest < ActiveSupport::TestCase
  
  test "should be able to retrieve projects based on day" do
    actual = projects(:huddle).reports_grouped_by_day
    expected_keys = actual.keys.sort.map{ |d| d.to_s(:db) }
    assert_equal(["2009-01-06", "2009-01-07"], expected_keys)
    assert_equal([status_reports(:ben_tue).id, status_reports(:jerry_tue).id],
        actual[Date.parse("2009-01-06")].map(&:id))
  end

  test "lets stub an object" do
    stub_project = Project.new(:name => "Project Greenlight")
    stub_project.stubs(:name) 
    assert_nil(stub_project.name) 
  end

  test "lets stub an object again" do
    stub_project = Project.new(:name => "Project Greenlight")
    stub_project.stubs(:name).returns("Fred") 
    assert_equal("Fred", stub_project.name)
  end


  test "lets mock an object" do
    mock_project = Project.new(:name => "Project Greenlight")
    mock_project.expects(:name).returns("Fred")
    assert_equal("Fred", mock_project.name)
  end


  test "let's stub a class" do
    Project.stubs(:find).returns(Project.new(:name => "Project Greenlight"))
    project = Project.find(1)  
    assert_equal("Project Greenlight", project.name)
  end


  test "let's stub a class again" do
    Project.stubs(:find).with(1).returns(
        Project.new(:name => "Project Greenlight"))
    Project.stubs(:find).with(2).returns(
        Project.new(:name => "Project Blue Book"))
    assert_equal("Project Greenlight", Project.find(1).name)
    assert_equal("Project Blue Book", Project.find(2).name)
  end


  test "a sample mock" do
    mocky = mock(:name => "Paul", :weight => 100)
    assert_equal("Paul", mocky.name)
    assert_equal(100, mocky.weight)
  end

  
end
